#!/bin/sh
#
# Copyright (C) Internet Systems Consortium, Inc. ("ISC")
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, you can obtain one at https://mozilla.org/MPL/2.0/.
#
# See the COPYRIGHT file distributed with this work for additional
# information regarding copyright ownership.

rm -f dig.out.*test*
rm -f delv.out.test*
rm -f host.out.test*
rm -f nslookup.out.test*
rm -f */named.memstats
rm -f */named.run
rm -f */named.conf
rm -f ./nsupdate.out.test*
